# Clip Operations API

## Wrapper clips

::: pymotion.clip.operations.SubClip
::: pymotion.clip.operations.JoinedClip
::: pymotion.clip.operations.ConcatenatedClip
::: pymotion.clip.operations.RepeatedClip
::: pymotion.clip.operations.FreezeFrameClip
::: pymotion.clip.operations.SpeedClip
::: pymotion.clip.operations.SpeedRampClip
::: pymotion.clip.operations.ReversedClip
::: pymotion.clip.operations.TimeRemappedClip

## Functions

::: pymotion.clip.operations.concatenate
